import { UseCase, MainUseCase } from '@curio/client'

export type Item = {
  _OID: string,
  _Codigo: string,
  _Descricao: string
}
export type Domain = {
  Tipo: [{Item: [Item]}],
  Projetos: [{Item: [Item]}]
}
export type Contexto = {
  Usuario: [{_Nome: string}],
  Domains: [Domain]
}

export type RegistroPonto = {
  _DataRegistro: string,
  _Tipo: string
}
export type IncluirRegistroPonto = {
  UltimoRegistroPonto?: [RegistroPonto],
  RegistroPonto: [RegistroPonto]
}

export type Tarefa = {
  TarefasFilhas: [{Tarefa: [Tarefa]}],
  _OID: string,
  _Descricao: string,
  _Ativo: 'S'|'N',
  _PermiteRegistro: 'S'|'N'
}
export type Tarefas = [{Tarefa: [Tarefa]}]
export type ObterTarefaProjeto = {
  Tarefas: Tarefas
}

export class UcRegistrarPonto extends UseCase {
  public static USECASEID = 788
  obterContexto (): Promise<Contexto> {
    return this.sendRequest('RM_OBTEM_CONTEXTO')
  }
  incluirRegistroPonto (): Promise<IncluirRegistroPonto> {
    return this.sendRequest('RM_INCLUIR_REGISTRO_PONTO')
  }
  confirmarRegistro () {
    return this.sendRequest('RM_CONFIRMAR_REGISTRO')
  }
  obterTarefaProjeto (codigo: number | string): Promise<ObterTarefaProjeto> {
    return this.sendRequest('RM_OBTEM_TAREFA_PROJETO', {OBJECTID: {_: codigo}})
  }
  incluirTarefa (_OID: number | string, time: number, _Descricao: string) {
    const _Hora = Math.floor(time / 60)
    const _Minuto = time % 60
    return this.sendRequest('RM_INCLUIR_TAREFA', {Tarefa: {_OID, _Hora, _Minuto, _Descricao}})
  }
}
